/*******************************************************************************
 viewer
*******************************************************************************/

.viewer {
  position: relative;
  top: 0;
  left: 0;
  background-color: #DDD;
  overflow: hidden;     
 
  /* NOTE: the size and width should be set dynamically when initialized */
  width: 0;
  height: 0;
}

.viewer img {
  margin: 0px;
  float: none;  
}

.viewer .well, .viewer .surface {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0px;
  left: 0px;
  /* FIXME: let's apply this in GSV.js */
  cursor: grab;
  cursor: -moz-grab;
  _cursor: url(images/grab.cur);
}

.viewer .surface {
  z-index: 20;
  _background: url(images/blank.gif) no-repeat center center; /* NOTE: required for IE to"see" the surface */
}

.viewer .well {
  overflow: hidden;
  z-index: 10;
}

.viewer .well .tile {
  border: 0;
  margin: 0;
  padding: 0;
  position: absolute;
  top: 0px;
  left: 0px;
  display: block;
}

/*******************************************************************************
 thumbnail
*******************************************************************************/

.viewer .thumbnail {
  position: absolute;
  right: 4px;
  bottom: 4px;
  width: 130px;
  height: 130px;
  margin: 0;
  font-size: 12px;
  line-height: 20px;
  vertical-align: middle;
  font-weight: bold;

  overflow: hidden; 
  z-index: 30;

  border: 1px solid #000000;
  
  opacity:0.8;
  filter:alpha(opacity=80);   
}

.viewer .thumbnail img {
  position: absolute;
  top: 0px;
  left: 0px;
  z-index: 30;
  overflow: hidden;
}

.viewer .thumbnail_scale {
  position: absolute;
  bottom: -2px;
  left: 5px;  
  margin: 0;
  padding: 0px;
  z-index: 45;
  color: #FFFFFF;
}

.viewer .thumbnail_roi {
  position: absolute;
  top: 0px;
  left: 0px;  
  width: 50px;
  height: 50px;
  margin: 0;
  padding: 0px;
  border: 2px solid #FF0000;
  z-index: 40;
}

.viewer .thumbnail_roi_preview {
  position: absolute;
  top: 0px;
  left: 0px;  
  width: 50px;
  height: 50px;
  margin: 0;
  padding: 0px;
  border: 2px solid #FFFF00;
  z-index: 39;
}

.viewer .thumbnail_surface {
  position: absolute;
  top: 0px;
  left: 0px;  
  z-index: 50;
  width: 100%;
  height: 100%;  
}

/*******************************************************************************
 info
*******************************************************************************/

.viewer .info {
  position: absolute; 
  z-index: 25; 
  width: 100%;
  text-align: left; 
  left: 0px; 
  padding: 5px; 
  bottom: 0px; 
  color: #FFFFFF; 
  text-shadow: 1px 1px 1px #000000; 
  font-size: 12px;
  text-overflow: ellipsis;  
}
