body {
    margin: 0;
    font-size: 13px;
    font-family: Arial, Verdana, Lucida, Helvetica, sans-serif;
    color: #555;
    padding: 0;
    background-color: #f3f3f3;
}

.error {
    color: #e3646f;
}

a {
    color: #1b7bc7;
    text-decoration: none;
    border: none;
}
a:hover,a:link,a:visited {
    color: #1b7bc7;
    text-decoration: none;
    border: none;
}

h1 {
    font-size: 15px;
    text-align: left;
    margin: 0;
    padding: 10px 0;
}
h2 {
    font-size: 12px;
    text-align: left;
}

.bodyWrapper {
    width: 600px;
    margin: 5px auto;
}

.logo_list {
    display: flex;
    align-items: center;
}

.logo_list li {
    display: inline-block;
    margin-right: 10px;
    margin-bottom: 5px;
}

.logo_list .middle_logo {
    margin-right: 15px;
}

.version_list li {
    margin-top: 7px;
}

.version_chip {
    background-color: #dfdfdf;
    border: 1px solid #afafaf;
    margin-right: 2px;
    margin-left: 2px;
    padding: 1px;
    border-radius: 10%;
    font-size: 9px;
}