/**
 * omero_image - style definitions
 * 
 * Copyright (c) 2007, 2008 Glencoe Software, Inc. All rights reserved.
 * 
 * This software is distributed under the terms described by the LICENCE file
 * you can find at the root of the distribution bundle, which states you are
 * free to use it only for non commercial purposes.
 * If the file is missing please request a copy by contacting
 * jason@glencoesoftware.com.
 */

html {
  overflow: hidden;
  height: 100%;
}

body {
  overflow: hidden;
}

a {
  text-decoration: none;
}

#body { 
  clear: both;
}

#header {
  padding: 0;
  margin: 0;
}

#header span {
  /*margin: 20px;*/
  padding-top:5px;
}

#header span p {
  font-size: 1.0em;
  margin: 0px;
  padding: 0px;
}

/*
#header img { 
  margin: 0.5em;
  padding: 0;
}
*/
#header ul { 
  text-align: left;
  list-style-type: none;
  padding-top: 1.5em;
}

hr { 
  display: block;
  margin: 0px;
  padding: 0 0 0 0;
  clear: both;
  height: 10px;
}

#wblitz { 
  clear: both;
  display: block;
  position: relative;
  width: 100%;
  height: 100%;
  padding-top: 5px;
}

.centeredImage {
  display: block;
  margin-top:0px;
  margin-bottom:0px;
  margin-left: auto;
  margin-right: auto;
  padding:0px;
}

.box { 
  display: block;
  background-color: #eee;
  border: 1px solid #bbb;
  padding: 0px;
  text-align: center;
  width: 150px;
  overflow: hidden;
  font-size: 0.8em;
}

.box .row {
  padding-bottom: 3px;   
}

.odd {
  background-color: #eee;   
}

.even {
  background-color: #eee;   
}

/*

.box.popover { 
  _width: 200px;
  z-index: 1;
}

.box.popover h1 { 
  cursor: pointer;
  padding: 0 5px;
  text-decoration: underline;
}

.box.popover .detail { 
  display: none;
  margin-bottom: 0.5em;
}

.detail ul { 
  margin-top: 0;
  padding-top: 0;
  text-align: left;
  list-style-type: none;
  padding-left: 30%;
  _padding-left: 5%;
}

.detail .selected { 
  background: #a4afb5;
}

.detail a { 
  display: block;
  margin: 2px;
}
   
   */

.box.popover.popped .detail { 
  position: relative;
  display: block;
}

.drop-img {
  display: inline;
  width: 10px;
  height: 16px;
  background: url('../img/white_arrow_up.gif') no-repeat center;
}

.popped .drop-img { 
  background: url('../img/white_arrow_up.gif') no-repeat center;
}

.drop-left { 
  float: left;
}

.box .drop-right { 
  float: right;
}

/*

.box.popover.popped .not-detail { 
  display: none;
}
   
   */

.box.popped { 
  height: auto;
  overflow: auto;
}

.box h1 { 
  font-size: 1.0em;
  display: block;
  margin: 0px;
  font-weight: bold;
  border-bottom: 1px solid #bbb;
  padding: 5px;
  background-color: #fff;
  color: #555;
}

.box h2 { 
  display: block;
  margin: 0px;
  margin-top: 0em;
  margin-bottom: 3px;
  font-size: 1.0em;
  font-weight: bold;
  text-decoration: none;
}

.h2-lookalike {
  display: block;
  margin: 0px;
  margin-top: 0.5em;
}

.box input {
  margin: 4px 0 0 4px;
}

.box select {
  font-size: 0.8em;
}

.box table {
  width: 100%;
  text-align: center;
  margin: 0.5em; 
  font-size: 1.0em;
}

.box td { 
  text-align: left;
}

.box td.key { 
  text-align: right;
  width: 30%;
}

.tooltipbox {
  display: none;
  position: absolute;
  background-color: #eee;
  z-index: 50;
  border: solid 1px #bbb;
}

.tooltipbox td {
  font-size: 0.8em;
  font-weight: bold;
}

.tooltipbox.popped { 
  display: block;
}

#wblitz-workarea {    
  display: block;
  padding: 0;
  margin: 0;
  position: relative;
  width: 100%;
  height: 100%
  overflow: hidden;
}

#wblitz-workarea .box {
  display: block;
/*  float: left;
  position: relative; */
  margin: 0px 5px 5px 5px;
}

#wblitz-workarea button#full-size {
  background: url('../img/1_1.gif') no-repeat center;
  height: 22px;
  width: 22px;
  padding: 0;
  margin-bottom: 4px;
  margin-left: 0px;
}

#wblitz-workarea button#full-screen {
  background: url('../img/fs.gif') no-repeat center;
  height: 22px;
  width: 22px;
  padding: 0;
  margin-bottom: 4px;
  margin-left: 0px;
}


button.pressed {
  border-style: inset;
}

.forcegrey { 
  background-color: grey !important;
  color: white;
}

.popclose { 
  cursor: pointer;
}

.postit { 
  background-color: #eee;
  font-size: 0.9em;
}

.postit h1 {
  background-color: #bbb;
  color: #fff;
}

.postit table { 
  font-size: 0.9em;
  margin-left: auto;
  margin-right: auto;
}

.postit .even-row {
  background-color: #D1D3D5;   
}

.postit button .preset-color-btn{
  width: 18px;
  height: 16px;
  padding: 0px;
  margin: 0px;
}


#metadata-postit { 
  width: 400px;
}

.chan-window-slider { 
  position: relative;
  display: block;
  height: 15px;
  clear: both;
}

#cbpicker-box { 
  _width: 197px;
}


/* Viewport thingies */
#weblitz-viewport { 
  position: absolute;
  clear: both;
  display: block;
  top: 0px;
  left: 190px;
  height: 300;
  width: 400;
}

/* Specific postit stuff */
#metadata-postit {
  /* max-width: 600px; */
}

#roi_table_postit table {
    width: 100%;
}

.thumbslider {
  position: absolute;
  left: 165px;
  display: block;
}

div.labeledBox {
  margin: 0.5em;
  margin-top: 1em;
  border: 1px solid;
  text-align: left;
}

div.labeledBox label {
  position: relative;
  top: -1em;
  left: 0.2em;
}

img.figure-box-hide {
  position: absolute;
  right: -16px;
  top: 7px;
  cursor: pointer;
}

.postit li {
  margin-bottom: 0.5em;
  text-align: center;
}

#metadata-postit li > strong {
  width: 125px;
  text-align: right;
  display: block;
  float: left;
}

#sizes-postit li > strong {
  width: 30px;
  text-align: right;
  display: block;
  float: left;
}

#metadata-postit table, #sizes-postit table {
  width: 100%;
}

.dimensions th {
  text-align: center;
}

.dimensions td.title {
  text-align: right;
  width: 20%;
}

td.title {
  text-align: right;
  font-weight: bold;
}

#z-axis-legend {
  position: absolute; 
  left: 160px;
  height: 80px;
  width: 25px;
}

#t-axis-legend {
  position: absolute;
  left: 155px;
  height: 26px;
  width: 80px;
}

.odd .multiselect {
  background-color: #fff;
}

.even .multiselect {
  background-color: #fff;
}


.multiselect {
  font-size: 0.8em;
  margin: 0 1em;
  padding: 5px 2px;
  text-align: left;
  position: relative;
}

.multiselect.selected {
  background-color: #504A45;
  color: white;
  font-weight: bold;
}

.multiselect input {
  left: 115px;
  margin: 0px;
  position: absolute;
}

*:first-child+html .multiselect input {
  top: 0px;
  left: 111px;
}

.postit h3 {
  background-color: #B2AEA8;
  color: #504A45;
  font-size:1em;
  font-weight:bold;
  text-align: center;
}

.postit h3.can-collapse {
  color: #000000;
  background-color: #C4DCE4;
}

.can-collapse {
  background: url('../img/white_arrow_up.gif') no-repeat 5px center;
  border: 1px solid #000000;
  border-bottom: none;
  margin: 3px 3px 0px 3px;
  cursor: pointer;
}

.can-collapse.closed {
  background-image: url('../img/white_arrow_down.gif');
}

.postit h3.can-collapse.closed {
  border: 1px solid #504A45;
  background-color: #B2AEA8;
  color: #504A45;
}

.can-collapse + div {
  border: 1px solid #000000;
  border-top: none;
  margin: 0px 3px 0px 3px;
}

.rangeslider {
  margin: 0.2em 1em 0.2em 1em;
  border: solid #333 1px;
}

.postit-help-btn {
  background-image:url(../img/question.png);
  background-position:center center;
  background-repeat:no-repeat;
  cursor:pointer;
  height:1.5em;
  position:absolute;
  right:1.2em;
  top:0;
  width:1.5em;
}

a#rdef-postit-help {
  float: right;
  margin-top: 1px;
  margin-right: 0.4em;
  background-color: transparent;
}

#rdef-postit-help img {
  border: none;
}

.ui-widget-content {
  border-color: #333333;
}

.ui-slider-handle.ui-state-default {
  background:#FEE7D6 none repeat scroll 0 0;
  border: solid #666 1px;
}

.ui-slider-handle.ui-state-focus, .ui-slider-handle.ui-state-hover {
  border-color:#F95916;
}

#cbpicker-box div span {
  margin-right: 1em;
}

input.spin-button {
  text-align: right;
}

.rangewidget {
  margin-top: 0.5em;
}

.rangewidget input {
  width: 4.5em;
}

#rdef-postit table {
  width:100%;
}

.postit table th {
  background-color:#B2AEA8;
  color:#504A45;
}

#rdef-postit .odd {
  background-color: #FFFFFF;   
}

#rdef-postit .even {
  background-color: #C4CFD5;   
}

/* Styles for the ROI table */
#roi_table_postit {
    width:340px;
}
#roi_table_div {
    overflow-y: scroll;
    max-height: 500px;
}
#roi_small_table th {
    background-color: #ccc; 
    padding: 1px;
    max-width:100px;
    border: solid #eee 1px;
}
#roi_small_table th p {
    text-align: center;
    max-width:100px;
    word-wrap:break-word;
    padding: 0px;
    margin: 0px;
}
#roi_small_table td {
    background-color: #fff;
    max-width:100px;
    text-align: center;
    border: solid #eee 1px;
    padding: 0px;
}
#roi_small_table td p {
    text-align: center;
    max-width:100px;
    word-wrap:break-word;
    padding: 0px;
    margin: 0px;
}
#roi_small_table td.icon {
    background-color: #fff;
    text-align: left;
    white-space: nowrap;
    width: 50px;
}
#roi_small_table .only_child td {
    background-color: #ddd;
}

#roi_small_table .shape_cell {
    cursor: pointer;
    position: relative;
}
#roi_small_table .roi_row th {
    cursor: pointer;
    position: relative;
}
#roi_thumb_popup {
    position: absolute;
    z-index: 250;
    display: none;
}
.color_picker_option {
    float: left;
    width: 8px;
    height: 10px;
}
/* histogram svg */
.line {
  fill: none;
}
