/**
 * weblitz_viewport - style definitions
 * 
 * Copyright (c) 2007, 2008, 2009 Glencoe Software, Inc. All rights reserved.
 * 
 * This software is distributed under the terms described by the LICENCE file
 * you can find at the root of the distribution bundle, which states you are
 * free to use it only for non commercial purposes.
 * If the file is missing please request a copy by contacting
 * jason@glencoesoftware.com.
 *
 * Author: Carlos Neves <carlos(at)glencoesoftware.com>
 */

/*div.weblitz-viewport-tiles {
  background: transparent;
  margin: 0;
  overflow: hidden;
  padding: 0;
  position: absolute;
  white-space: nowrap;
}
div.weblitz-viewport-tiles img {
 border: medium none;
 margin: 0;
 padding: 0;
 position: absolute;
}*/
  
  
.weblitz-viewport-vp {
  position: absolute;
  display: block;
  border: 1px solid;
  margin: 0px;
  padding: 0px;
  height: 100%;
  width: 100%;
  overflow: hidden;
  background-color: #ddd;
  top: 0px;
  left: 15px;
}

.weblitz-viewport-top { 
  position: relative;
  height: 100%;
}

.weblitz-viewport-bot { 
  position: relative;
  left: 15px;
  height: 15px;
}

.weblitz-viewport-scalebar {
  display: none;
  font-size: 12px;
  font-color:#000;
  text-align: center;
  border: 1px solid #000;
  background: rgba(255, 255, 255, 0.7);
  position: absolute;
  bottom: 50px;
  left: 50px;
  width: 0px;
  height: 15px;
  z-index: 1000;
}

.weblitz-viewport-msg {
  display: none;
  color: #F30;
  font-weight: bold;
  position: absolute;
  top: 0.5em;
  right: 0.5em;
  z-index: 1000;
}

.weblitz-viewport-img {
  position: absolute;
  top: 0px;
  left: 0px;
}

/* Customizing the jquery-plugin-viewportImage classes */

.image-viewer { 
  position: relative;
}

.vslider { 
  position: absolute;
  width: 13px;
  height: 100%;
  display: block;
  top: 0px;
  left: 1px;
}

.hslider { 
  position: relative;
  height: 13px;
  /*bottom: -3px;*/
  display: block;
  font-size: 0.1em;
}

.slider-line { 
  /* width: 100%; */
  background: #FFF;
  font-size: 0.1em;
}

.slider-handle { 
  background: #184A89;
  font-size: 0.1em;
  left: -1px; 
  top: -1px;
}

.draggable {
  cursor: -moz-grab;
  cursor: pointer, auto;
}

.ondrag {
  cursor: -moz-grabbing;
  cursor: hand, auto;
}

.pick-pos {
  cursor: crosshair;
}

.viewer {
  z-index: 19;
}

.wb_zoomIn, .wb_zoom11, .wb_zoomOut {
  position: absolute;
  z-index: 1;
  left: 10px;
  width: 20px;
}

.rd-wblitz-ch {
  margin-right: 5px;
  padding: 1px 2px;
  white-space: nowrap;
}

.squared div {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
}
.btnLabel {
  padding: 1px;
}

.squared {
  width: 49px;
  height: 19px;
  position: relative;
}

.fontWhite {
  color: white;
}

/* from http://phrogz.net/tmp/canvas_image_zoom.html */
.pixelated {
  image-rendering:optimizeSpeed;             /* Legal fallback */
  image-rendering:-moz-crisp-edges;          /* Firefox        */
  image-rendering:-o-crisp-edges;            /* Opera          */
  image-rendering:-webkit-optimize-contrast; /* Safari         */
  image-rendering:optimize-contrast;         /* CSS3 Proposed  */
  image-rendering:crisp-edges;               /* CSS4 Proposed  */
  image-rendering:pixelated;                 /* CSS4 Proposed  */
  -ms-interpolation-mode:nearest-neighbor;   /* IE8+           */
}

.lutBackground {
  background-image: url('../img/luts_10.png');
  background-repeat: no-repeat;
  image-rendering: pixelated;
}
button>.lutBackground {
  opacity: 0.3;
}

