{% load i18n %}

<!--
  This template is no-longer used by omero-web
  Since it will be removed soon, we need to be sure that any users are warned:
-->
<script>alert("WARNING: Django template webclient/index/index_most_recent.html has been deprecated")</script>

{% comment %}
<!--
  Copyright (C) 2011 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}



<div class="clear"></div>

<hr/>

<h2>{% trans "Most recent share comments" %}:</h2>
{% if controller.mostRecentSharesComments %}
    <table>
        <tbody>
        {% for cm in controller.mostRecentSharesComments %}
            <tr><td>
                <img src="{% static "webgateway/img/knotes16.png" %}" title="comment" alt="comment"/> {{ cm.getComment.getOwner.getFullName }}</a> {% trans "commented the" %} <a href="{% url 'load_template' "public" %}">{% trans "share" %} {{ cm.link.id }}</a> on {{ cm.getComment.creationEventDate|date:"Y-m-d H:i:s" }}
            </td></tr>
        {% endfor %}
        </tbody>
    </table>
{% else %}
    <div><p>{% trans "No data commented." %}</p></div>
{% endif %}

<hr/>

<div class="clear"></div>


<h2>{% trans "Most recent shares" %}:</h2>
{% if controller.mostRecentShares %}
    <table>
        <tbody>
        {% for sh in controller.mostRecentShares %}
            <tr><td>
                <a href="{% url 'load_template' "public" %}">{% trans "share" %} {{ sh.id }}</a> owned by {{ sh.getOwner.getFullName }}
            </td></tr>
        {% endfor %}
        </tbody>
    </table>
{% else %}
    <div><p>{% trans "No data commented." %}</p></div>
{% endif %}
