/**
 * jquery-plugin-colorbtn - style definitions
 * 
 * Copyright (c) 2007, 2008 Glencoe Software, Inc. All rights reserved.
 * 
 * This software is distributed under the terms described by the LICENCE file
 * you can find at the root of the distribution bundle, which states you are
 * free to use it only for non commercial purposes.
 * If the file is missing please request a copy by contacting
 * jason@glencoesoftware.com.
 */

.cbpicker input {
  text-align: center;
  width: 6em;
  font-size: 1.2em;
}

/*.cbpicker {
    font-size: 0.7em !important;
}*/

.picker {
	background: url('../img/colorpicker_16.png') center center no-repeat;
	border-width: 0;
	width: 18px;
	height: 18px;
	border-radius: 3px;
	margin-left: 5px;
}

.lutpicker {
	height: 300px;
	overflow: scroll;
}
.lutpicker input {
	display: none;
}
.lutpicker label {
	font-size: 12px;
	font-weight: normal;
	width: 100%;
	display: block;
}
.lutpicker label:hover {
	background-color: #ddddff;
}
.lutpicker label span {
	display: inline-block;
	width: 50px;
	margin: 4px;
}
.lutpicker input {
	width: 10px;
}
#invert {
	display: block;
	float: left;
}