/* 	
	----------------------------------------------------

	Dusty
	
	The OME UI Elements Library
	Domenico Gaudioso
	
	----------------------------------------------------
 */



	
/* 	
	----------------------------------------------------

	Table Of Contents:
	
	
	:: Buttons - Generic (.btn)
		:: Button - Blue (.btn.blue)
		:: Button - Silver (.btn.silver)

	:: Tags

	:: Context Box - Generic
		:: Context Box - Dark
	
	
	----------------------------------------------------
 */
	








/*
	------------------------------------------------
	:: Buttons - Generic
	------------------------------------------------
*/


		/* Singular Buttons */
		.btn{
			-webkit-border-radius:3px;
			-moz-border-radius:3px;
			border-radius:3px;
		}
		
		
	
			.btn span{
				-webkit-border-radius:inherit;
				-moz-border-radius:inherit;
				border-radius:inherit;
			}
			
			
		
		
		/* Menu Buttons */

			
			.menu_btns li:first-child {
				
				 -webkit-border-bottom-left-radius:4px;
				 -moz-border-radius-bottomleft:4px;
				 border-bottom-left-radius:4px;		
				 		 
				 -webkit-border-top-left-radius:4px; /* Saf3+, Chrome */
				 -moz-border-radius-topleft:4px; /* FF1+ */
				 border-top-left-radius:4px; /* Opera 10.5, IE 9 */ 
			}
			
			
			.menu_btns li:last-child {
				
				-webkit-border-bottom-right-radius:4px; /* Saf3+, Chrome */
				-moz-border-radius-bottomright:4px; /* FF1+ */
				border-bottom-right-radius:4px; /* Opera 10.5, IE 9 */
				
				-webkit-border-top-right-radius:4px;
				-moz-border-radius-topright:4px;
				border-top-right-radius:4px; 
				
			}
			
			
	
	

/*
	------------------------------------------------
	:: Button - Blue
	------------------------------------------------
*/

		
		.btn.blue {
			background-color: #7099C2;
			border:solid 1px #5980A6;
			border-bottom:solid 1px #476685;
		}
		
		.btn.blue:hover {
			background-color:#82A6C9;
		}
		
		
		
			.btn.blue span {
				color: #1A334D;
				text-shadow:0 1px 0 rgba(255,255,255,.3);
				-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Saf3.0+, Chrome */
				   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* FF3.5+ */
				        box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Opera 10.5, IE 9.0 */

				filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='rgba(255,255,255,.2)', endColorstr='rgba(255,255,255,0)',GradientType=0 ); /* IE6-9 */

			}
			

			.btn.blue:active span, .btn.blue:focus span{
				filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='rgba(255,255,255,0)', endColorstr='rgba(255,255,255,.2)',GradientType=0 ); /* IE6-9 */
			}
			
			




/*
	------------------------------------------------
	:: Button - Silver
	------------------------------------------------
*/

		
		
			
			
		/* State */	
		
			
			
		.menu_btns.silver {
			border-top:solid 1px #e6e6e6;
			border-left:solid 1px #CCCCCC;
			border-right:solid 1px #CCCCCC;
			border-bottom:solid 1px #CCCCCC;

			-webkit-border-radius:4px; /* Saf3+, Chrome */
			   -moz-border-radius:4px; /* FF1+ */
			        border-radius:4px; /* Opera 10.5, IE 9 */ 

			-webkit-box-shadow:0 1px 0 white;
		}
		
		
		
			.btn.silver, .menu_btns.silver li {
				background-color: #E3E6E8;
				border:solid 1px blue;
				color: #494D50;
				text-shadow: 0 1px 0 white;
			}
		
			.btn.silver {
				border:solid 1px #9FA6AD;
				
				-webkit-box-shadow: 0 1px 0 rgba(255,255,255,0.5); /* Saf3.0+, Chrome */
				   -moz-box-shadow: 0 1px 0 rgba(255,255,255,0.5); /* FF3.5+ */
				        box-shadow: 0 1px 0 rgba(255,255,255,0.5); /* Opera 10.5, IE 9.0 */
			}
			
			.menu_btns.silver li {
				border-left: solid 1px rgba(255,255,255,.3);
				border-right:solid 1px #E6E6E6;
			}
			
			
				.menu_btns.silver a {
					color:#494D50;
					
					-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.4); /* Saf3.0+, Chrome */
					   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.4); /* FF3.5+ */
					        box-shadow:inset 0 1px 0 rgba(255,255,255,0.4); /* Opera 10.5, IE 9.0 */
							
					filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#EBECEE', endColorstr='#E4E6E8',GradientType=0 ); 

				}

				
		
		
		
		
		/* Hover */	
		
		.btn.silver:hover, .menu_btns.silver li:hover {
			background-color: #EEF0F1;
			
		}
		
		
		
		/* Active, Focus */
		
		.btn.silver:active, .btn.silver:focus, .menu_btns.silver li:active, .menu_btns.silver li:focus {
			background-color:#ACB3B9;
			border:solid 1px #838C95;
			border-top:solid 1px #717A84;
		}
		
		
		.menu_btns.silver li:active, .menu_btns.silver li:focus {
			border-left: solid 1px #CCCCCC;
			border-right:solid 1px transparent;
		}
		
		
			.btn.silver:active span, .btn.silver:focus span{
				filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#CBCBCB', endColorstr='#DBDBDB',GradientType=0 ); /* IE6-9 */
			}
			
			.menu_btns.silver li:active a, .menu_btns.silver li:focus a {
				border-top:solid 1px rgba(0,0,0,.4);
				filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#CBCBCB', endColorstr='#DBDBDB',GradientType=0 ); 	
			}
	



			.btn_view {background: transparent url('../../webgateway/img/icon_view.png') center center no-repeat;}
			.btn_folder {background:  transparent url('../../webgateway/img/icon_folder.png') center center no-repeat;}
			.btn_download {background:  transparent url('../../webgateway/img/icon_download.png') center center no-repeat;}
			.btn_filetype {background:  transparent url('../../webgateway/img/icon_filetype.png') center center no-repeat;}
			.btn_view_error {background:  transparent url('../../webgateway/img/icon_view_error.png') center center no-repeat;}
			.btn_info {background:  transparent url('../../webgateway/img/icon_info.png') center center no-repeat;}
			.btn_add {background:  transparent url('../../webgateway/img/icon_add.png') center center no-repeat;}
			.btn_edit {background: transparent url('../../webgateway/img/icon_edit.png') center center no-repeat;}
			.btn_link {background: transparent url('../../webgateway/img/icon_link.png') center center no-repeat; 
        	    float:right;
        	    position: relative}

        	.btn_link span {
        	    width:29px;
        	    height:18px;
        	    display:block;
        	}
			
			
			

			a.btn_add span, a.btn_edit span, button.btn_add span, button.btn_edit span {
				width:20px;
				height:18px;
				display:block;
			}






/*
	------------------------------------------------
	:: Tags
	------------------------------------------------
*/
    
    
.tag .tag_inner{
	text-shadow: 0 1px 0 rgba(255,255,255,.8);
	border:solid 1px #70A0C2;
	filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#D6E8F5', endColorstr='#CBDBE6',GradientType=0 ); /* IE6-9 */
	color: #3E5E74;
}
    
.tag .tag_inner:hover {
	filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#ABD2ED', endColorstr='#93C7EC',GradientType=0 ); /* IE6-9 */
	text-shadow: 0 1px 0 rgba(255,255,255,.4);
	color: #365063;        
}


.removeTag {
	color: #8599AD;
	text-shadow: 0 1px 0 rgba(255,255,255,.7);

	-webkit-border-radius:20px;
	-moz-border-radius:20px;
	border-radius:20px;
}


.removeTag:hover {
	background-color: #70A0C2;
	color: #3D4C5C;
	text-shadow: 0 1px 0 rgba(255,255,255,.5);
}








/*
	------------------------------------------------
	:: Form
	------------------------------------------------
*/

	
	.standard_form .required label { 
        color: #E3646F;
    }
		.standard_form label {
			color: #737F8C;
			text-shadow: 0 1px 0 white;
		}
		
		
		



	.standard_form input[type=text], input[type=password], textarea {
		border: solid 1px rgba(0,0,0,.2);
		border-top: solid 1px rgba(0,0,0,.3);
		-webkit-box-shadow: 0 1px 0 white, inset 0 1px 1px rgba(0,0,0,.1);
		-moz-box-shadow: 0 1px 0 white, inset 0 1px 1px rgba(0,0,0,.1);
		box-shadow: 0 1px 0 white, inset 0 1px 1px rgba(0,0,0,.1);
		-webkit-border-radius: 2px;
		-moz-border-radius: 2px;
		border-radius: 2px;
		color:#333;
	}
			
	.standard_form input[type=text]:focus, input[type=password]:focus, input[type=text]:active, input[type=password]:active {
		border:solid 1px #667F99;
	}
	
			
			
			
	.standard_form input[type="submit"] {
		background-color: #6699CC;
		filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#94B2D1', endColorstr='#7099C2',GradientType=0 ); /* IE6-9 */
		
		border-top:solid 1px #4D7FB3;
		border-right:solid 1px #3D668F;
		border-left:solid 1px #3D668F;
		border-bottom:solid 1px #36597D;
		
		-webkit-border-radius:3px;
		-moz-border-radius:3px;
		border-radius:3px;
		
		-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 1px rgba(0,0,0,.3);
		-moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 1px rgba(0,0,0,.3);
		box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 1px rgba(0,0,0,.3);
	
		color: #08192B;
		text-shadow: 0 1px 0 rgba(255,255,255,.3);
	}
			
			
			
	.standard_form input[type="submit"]:hover {
		filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#A9C2DA', endColorstr='#7099C2',GradientType=0 ); /* IE6-9 */
	}
			
	.standard_form input[type="submit"]:active, input[type="submit"]:focus {
		
		filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#7099C2', endColorstr='#82A6C9',GradientType=0 ); /* IE6-9 */
		
		-webkit-box-shadow:none    ; /* Saf3.0+, Chrome */
		   -moz-box-shadow:none    ; /* FF3.5+ */
		        box-shadow:none    ; /* Opera 10.5, IE 9.0 */
		
		border:solid 1px #3D668F;
	}
	
	







/*
	------------------------------------------------
	:: Datepicker
	------------------------------------------------
*/


	.ui-datepicker {
		border: #D5D9DD;
		background-color: #FFFFFF;
		
		-webkit-border-radius:3px; /* Saf3+, Chrome */
		   -moz-border-radius:3px; /* FF1+ */
		        border-radius:3px; /* Opera 10.5, IE 9 */ 
				
		-webkit-box-shadow:    0 4px 8px rgba(0,0,0,0.3), 0 0 1px rgba(0, 0, 0, 0.5); /* Saf3.0+, Chrome */
		   -moz-box-shadow:    0 4px 8px rgba(0,0,0,0.3), 0 0 1px rgba(0, 0, 0, 0.5); /* FF3.5+ */
		        box-shadow:    0 4px 8px rgba(0,0,0,0.3), 0 0 1px rgba(0, 0, 0, 0.5); /* Opera 10.5, IE 9.0 */
	}

	
		/* Header */

		.ui-datepicker-header {
			background-color: #E4E6E7;
			border-bottom:solid 1px #B9BFC6;
			
			filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#c6c6c6', endColorstr='#c6c6c6',GradientType=0 ); /* IE6-9 */
			background:linear-gradient(top, rgba(255,255,255,.3) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
		}
		
			.ui-datepicker-prev, .ui-datepicker-next {
				border:solid 1px #c6c6c6;
			
				-webkit-box-shadow: 0 1px 0 rgba(255,255,255,0.4); /* Saf3.0+, Chrome */
				   -moz-box-shadow: 0 1px 0 rgba(255,255,255,0.4); /* FF3.5+ */
				        box-shadow: 0 1px 0 rgba(255,255,255,0.4); /* Opera 10.5, IE 9.0 */
			
				-webkit-border-radius:2px; /* Saf3+, Chrome */
				   -moz-border-radius:2px; /* FF1+ */
				        border-radius:2px; /* Opera 10.5, IE 9 */ 
			}
			
			
			
			.ui-datepicker-prev:hover, .ui-datepicker-next:hover {
				background-color:rgba(255,255,255,.1);
			}
			
		
	
		/* Days */
		
		.ui-datepicker thead{
			background-color:#C6D9EC;
			filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='rgba(255,255,255,.2)', endColorstr='rgba(255,255,255,0)',GradientType=0 ); /* IE6-9 */
			background:linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,0) 100%); /* W3C */ 
		}
	
			.ui-datepicker thead th {
				border-right:solid 1px #B3CCE6;
				border-bottom:solid 1px #C2CCD6;
				
				-webkit-box-shadow: 1px 0 0 rgba(255,255,255,0.3), inset 0 1px 0 rgba(255,255,255,.3); /* Saf3.0+, Chrome */
				   -moz-box-shadow: 1px 0 0 rgba(255,255,255,0.3), inset 0 1px 0 rgba(255,255,255,.3); /* FF3.5+ */
				        box-shadow: 1px 0 0 rgba(255,255,255,0.3), inset 0 1px 0 rgba(255,255,255,.3); /* Opera 10.5, IE 9.0 */
				
				color: #476685;
				text-shadow: 0 1px 0 rgba(255,255,255,.9);
			}



		/* Numbers */
	
		.ui-datepicker tbody td:hover {
			
		}
	
			.ui-datepicker tbody td:hover a{
			    background-color: #4D88B3;
				color:white;
			}
	
			.ui-datepicker tbody a{
				color:#999;
			}







/*
	------------------------------------------------
	:: Dialog/Modal Boxes
	------------------------------------------------
*/

.ui-widget-overlay {
	background:rgba(255,255,255,.6);
}



.ui-dialog {
	background-color: #F6F7F9;
	
	-webkit-border-radius:6px; /* Saf3+, Chrome */
	   -moz-border-radius:6px; /* FF1+ */
	        border-radius:6px; /* Opera 10.5, IE 9 */ 
	
	border:solid 1px rgba(0,0,0,.1);
}


.ui-dialog-titlebar {
	
	-webkit-border-top-left-radius:5px; /* Saf3+, Chrome */
	-webkit-border-top-right-radius:5px;
 	-moz-border-radius-topleft:5px; /* FF1+ */
	-moz-border-radius-topright:5px;
    border-top-left-radius:5px; /* Opera 10.5, IE 9 */ 
    border-top-right-radius:5px; 
	
	filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#E3E6E8', endColorstr='#D5D9DD',GradientType=0 ); /* IE6-9 */

	-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.2); /* Saf3.0+, Chrome */
	   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.2); /* FF3.5+ */
	        box-shadow:inset 0 1px 0 rgba(255,255,255,0.2); /* Opera 10.5, IE 9.0 */
	
	border-bottom:solid 1px #C7CCD1;
}

	.ui-dialog-title{
		color: #5C6670 !important;
		text-shadow:0 1px 0 white;
	}
		
	.ui-dialog h1{
		text-shadow:0 1px 0 white;
	}



.ui-dialog .ui-dialog-buttonpane { 
	background-image: none;
	background-color: #F2F2F3;
	border-top:solid 1px #D7D9DB;
}

		.ui-dialog .ui-dialog-buttonpane button { 
			background:#C8CCD0; /* Old browsers */

			-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Saf3.0+, Chrome */
			   -moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* FF3.5+ */
			        box-shadow:inset 0 1px 0 rgba(255,255,255,0.1); /* Opera 10.5, IE 9.0 */

			color:#333;

			text-shadow:0 1px 0 rgba(255, 255, 255, 0.7);
			-webkit-border-radius:3px; /* Saf3+, Chrome */
			   -moz-border-radius:3px; /* FF1+ */
			        border-radius:3px; /* Opera 10.5, IE 9 */ 

			border:solid 1px #ACB3B9; 
		}
		
		.ui-dialog .ui-dialog-buttonpane button:hover { 
			background: #D6D9DC;
		}
		
		.ui-dialog .ui-dialog-buttonpane button:active, .ui-dialog .ui-dialog-buttonpane button:focus { 
			background: #C8CCD0; /* Old browsers */
			filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='rgba(255,255,255,0)', endColorstr='rgba(255,255,255,.2)',GradientType=0 ); /* IE6-9 */
			background:linear-gradient(top, rgba(255,255,255,0) 0%,rgba(255,255,255,.2) 100%); /* W3C */ 
		}
		









/*
	------------------------------------------------
	:: Search
	------------------------------------------------
*/

 


	#search input[type=text], .filtersearch input[type=text] {
		-webkit-border-radius:50px;
		-moz-border-radius:50px;
		border-radius:50px;
		
		border:solid 1px #6C7C93;
		border-top:solid 1px #525E6F;

		color:#333;

		-webkit-box-shadow: 0 1px 0 rgba(255,255,255,.2), inset 0 1px 1px rgba(0,0,0,.2);
		-moz-box-shadow: 0 1px 0 rgba(255,255,255,.2), inset 0 1px 1px rgba(0,0,0,.2);
		box-shadow: 0 1px 0 rgba(255,255,255,.15), inset 0 1px 2px rgba(0,0,0,.3);
	}

	
	
	/* Filter Search */
	
        .filtersearch input {
            border:solid 1px rgba(0,0,0,.6);
            border-top:solid 1px rgba(0,0,0,.6);
        }

        .filtersearch label {
            position:absolute;
            z-index:50;
            font-size:1.3em;
            font-weight:lighter;
            top:5px;
            left:8px;
        }
	
	    /* same as .filtersearch label for top search field */
    	.inline_label {
    	    position:absolute;
            z-index:50;
            font-size:1.3em;
            font-weight:lighter;
            top:5px;
            left:8px;
    	}	
















/* 
	----------------------------------------

	:: Context Box - Dark
	
	----------------------------------------  
*/





	.contextbox_dark {
		border: solid 1px red;
		width: 250px;
		padding: 10px;
		border: solid 1px black;
		-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.1);
		-moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.1);
		box-shadow: inset 0 1px 0 rgba(255,255,255,.1);
		-webkit-border-radius: 4px;
		-moz-border-radius: 4px;
		border-radius: 4px;
		background-color: hsl(210,0%,15%);
		font-size: 1.2em;
	}

		.contextbox_dark::after {
			background: url('../../webgateway/img/contextbox_arrowup.png') no-repeat;
		}

		.contextbox_dark h1 {
			color: white;
			text-shadow: 0 -1px 1px black;
		}

		.contextbox_dark .contextbox_inner {
			border:  solid 1px black;
			-webkit-box-shadow: 0 1px 0 rgba(255,255,255,.1);
			-moz-box-shadow: 0 1px 0 rgba(255,255,255,.1);
			box-shadow: 0 1px 0 rgba(255,255,255,.1);
		}


	
					.contextbox_dark li a {
						padding: 1em;
						font-weight: lighter;
						display: block;
						font-family: 'Helveticaneue-Medium', Helvetica, Arial, sans-serif;
						color: hsl(0,0%,20%);
						text-shadow: 0 1px 0 white;
					}


