/* Left Panel - Toolbar */

ul.toolbar {
    border-bottom: solid 1px hsl(210,10%,90%);
	border-right:solid 1px hsl( 210, 10%, 85% );
    overflow:hidden;
    background: none repeat scroll 0 0 #EFF1F4;
}

ul.labels {
    padding: 5px 0;
    margin: 3px 0;
}

ul.borderless {
    border-bottom-width: 0;
    border-right-width: 0;
}

    .toolbar li {
        float:left;
        position:relative;
		height:26px;
    }
	
    
        .toolbar input.button{
            background-color: transparent;
            vertical-align:middle;
            border: solid transparent 0;
            padding: 5px;
            color: gray;
            margin: 2px;
        }
        
        .toolbar button.button {
            background-color: transparent;
            border: solid transparent 0;
            padding: 0 3px;
            color: gray;
        }
    
        .toolbar input.button:hover , .toolbar button.button:hover {
            background-image: -webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,.2)), to(rgba(255,255,255,.4)));
			
			background-color:transparent; /* Old browsers */
			background-image:-moz-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(255,255,255,.2) 100%); /* FF3.6+ */
			background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,1)), color-stop(100%,rgba(255,255,255,.2))); /* Chrome,Safari4+ */
			background-image:-webkit-linear-gradient(top, rgba(255,255,255,1) 0%,rgba(255,255,255,.2) 100%); /* Chrome10+,Safari5.1+ */
			background-image:-o-linear-gradient(top, rgba(255,255,255,1) 0%,rgba(255,255,255,.2) 100%); /* Opera11.10+ */
			background-image:-ms-linear-gradient(top, rgba(255,255,255,1) 0%,rgba(255,255,255,.2) 100%); /* IE10+ */
			background:linear-gradient(top, rgba(255,255,255,1) 0%,rgba(255,255,255,.2) 100%); /* W3C */ 
					
            -webkit-transition: background .2s linear;
			
			-webkit-transition:background .2s linear;		
			   -moz-transition:background .2s linear;
			     -o-transition:background .2s linear;
			        transition:background .2s linear; 
			
            cursor:pointer;
        }
		
        .toolbar input.button:active, .toolbar input.button:focus {
            background: rgba(0,0,0,.1) -webkit-gradient(linear, left bottom, left top, from(rgba(255,255,255,.4)), to(rgba(255,255,255,.2)));
			
			background:rgba(0,0,0,.1); /* Old browsers */
			background-image:-moz-linear-gradient(top, rgba(255,255,255,.2) 0%, rgba(255,255,255,1) 100%); /* FF3.6+ */
			background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,1)), color-stop(100%,rgba(255,255,255,.4))); /* Chrome,Safari4+ */
			background-image:-webkit-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,1) 100%); /* Chrome10+,Safari5.1+ */
			background-image:-o-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,1) 100%); /* Opera11.10+ */
			background-image:-ms-linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,1) 100%); /* IE10+ */

			background:linear-gradient(top, rgba(255,255,255,.2) 0%,rgba(255,255,255,1) 100%); /* W3C */ 
			
			-webkit-box-shadow:inset 0 1px 2px rgba(0,0,0,.25);
			
			-webkit-box-shadow: 0 1px 2px rgba(0,0,0,0.25); /* Saf3.0+, Chrome */
			   -moz-box-shadow: 0 1px 2px rgba(0,0,0,0.25); /* FF3.5+ */
			        box-shadow: 0 1px 2px rgba(0,0,0,0.25); /* Opera 10.5, IE 9.0 */
			
            cursor:pointer;
			-webkit-transition:none;		
			   -moz-transition:none;
			     -o-transition:none;
			        transition:none 
        }
		
    
    
        .toolbar input.button-disabled, .toolbar button.button-disabled {
            opacity:0.2;
            cursor:default !important;
        }
    
    
        .toolbar input.button-disabled:hover, .toolbar button.button-disabled:hover {
            opacity:0.2;
            background:none;
            cursor:default !important;
        }
		
        .toolbar input.button-disabled:active, .toolbar input.button-disabled:focus, .toolbar button.button-disabled:active, .toolbar button.button-disabled:focus {
            -webkit-box-shadow:none;
			
			-webkit-box-shadow:none; /* Saf3.0+, Chrome */
			   -moz-box-shadow:none; /* FF3.5+ */
			        box-shadow:none; /* Opera 10.5, IE 9.0 */
			
			background:none;
			border-top:solid 1px transparent;
        }
		
    
        .seperator, .seperator2 {
            width:12px;
            height:8px;
            display:block;
            border:solid 1px transparent;
        }
    
        .seperator:before, .seperator2:before {
            content:'';
            width:1px;
            height: 8px;
            position:absolute;
            left:5px;
            top:9px;
        }
		
		.seperator:before {
			border-right:solid 1px rgba(255,255,255,1);
			background:hsl(210,10%,80%);
		}
    
	
		.seperator2:before {
			border-right:solid 1px rgba(255,255,255,.5);
			background:hsl(210,10%,70%);
		}
    
	

        .hiddenField {
            display: none;
        }


