{% extends "webgateway/core_html.html" %}
{% load i18n %}

{% block link %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static "feedback/css/layout.css" %}" type="text/css" />
{% endblock %}

{% block title %}
    {% trans "Web - Internal Error" %}
{% endblock %}

{% block body %}

<div class="error">
    <h1>
        {% trans "Go back to" %}: <a href="{% url 'webindex' %}" target="_top">{% trans "OMERO.web" %}</a>
    </h1>

{% block content %}
    <div class="error"><h1>{{ error }}</h1></div>
{% endblock %}

</div>
{% endblock %}
